<?php if (!defined('PmWiki')) exit();
/**
 * gridworks.php
 * @author V.Krishn (vkrishn@insteps.net), Copyright 2012-2023
 * @note This file is part of Cookbook recipe "GridWorks" for PmWiki;
 * You can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the  Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version. @see pmwiki.php for full details.
 *
 * @category pmwiki/cookbook
 * @package gridworks
 * @copyright Copyright (c) 2012-2023 V.Krishn (vkrishn@insteps.net)
 * @license GPL
 * @version 1.3.1
 */

global $GridWorks;
if ( ! IsEnabled($EnableGridWorks, 0)) return;

	## Current script variables
	if ( ! defined('DS') ) { define('DS', DIRECTORY_SEPARATOR); }
	$GridWorks['Current']['dir'] = dirname(__FILE__);
	if (file_exists($GridWorks['Current']['dir'] . DS . "version.php")) {
		include_once($GridWorks['Current']['dir'] . DS . "version.php");
	}

# improves full page edit performance, but preview would not be available
if ($action == 'edit') { return; }

// //////////////////////////////////////////////////////////
//
// (:grid columns=12 gutter=10 fluid=0 resetcss='main' loadmethod=js :)
//
//   columns    = 12|16|24 (default = 16)
//   gutter     = 10|20 (default = 20)
//   fluid      = 0|1 - Fluid set to '1' loads one stylesheet for given column.
//   resetcss   = 'main|text|all|normalize' - Loads extra css, reset.css and/or text.css
//   loadmethod = js|mq|mqcombo - Method of loading css, i.e Javascript(AdaptJs) or MediaQueries.
//   tablet     = 0|1 - for adapter unsemantic, loads grid css for tablets.
//   rtl        = 0|1 - loads Left-to-right config/orientation files (presently for unsemantic).
//
// //////////////////////////////////////////////////////////
if(function_exists('Markup_e')) {
  # new format, no /e , IMPORTANT: pmwiki-2.2.58+ and php 5.5x
  Markup('grid','directives', '/\\(:grid\\s(.*?):\\)/', 'CallbackGridWorks');
} else {
  /* old format, for pmwiki < 2.2.58
     if using php 5.5x see pmwiki documentation as how to suppress
       deprecated preg_replace errors. */
  Markup('grid','directives', '/\\(:grid\\s(.*?):\\)/e',
     "GridWorks(\$pagename, PSS('$1'))");
}

function CallbackGridWorks($m) {
  extract($GLOBALS["MarkupToHTML"]); # to get $pagename
  return GridWorks($pagename, $m[1]);
}

function _GridWorks($pagename, $args = '') {

	$str_args = $args;

	$defaults = array(
		'columns' => '16',
		'gutter' => '20',
		'fluid' => '0',
		'resetcss' => '',
		'loadmethod' => 'js',
		'showgrid' => '0',
		'tablet' => '0',
		'rtl' => '0',
		'loadcss' => 'all',
		'iecompat' => '0'
	);
	$args = ParseArgs($args);
	$args = array_merge($defaults, $args);

	$_columns = array( '12','16','24' );
	$_gutter = array( '10','20' );
	$_fluid = array( '0','1' );
	$_resetcss = array( 'main','text','all','normalize' );
	$_loadmethod = array( 'js','mq', 'mqcombo' );
	$_showgrid = array( '0','1','2' );
	$_tablet = array( '0','1' );
	$_rtl = array( '0','1' );
	$_loadcss = array($args['loadcss']);
	$_iecompat = array('0','1');

	foreach($defaults as $k=>$v) {
		$_t = $args[$k]; $s = "_".$k; $$k = $_t;
		if( !in_array($_t, $$s)) { $$k = $v; }
	}

	$gridworks = compact(array(
		'str_args', 'args', 'columns', 'gutter', 'fluid',
		'resetcss', 'loadmethod', 'showgrid', 'tablet' ,
		'rtl', 'loadcss', 'iecompat'
	));

	return $gridworks;

}

function _GridWorksLoadLib(&$gridworks) {

	global $GridWorks, $HTMLHeaderFmt;
	extract($gridworks, EXTR_OVERWRITE);
	/*
		Default libs
	*/
	return 'Css lib not set'; #use adapter to load css grid framework

}

function GridWorks($pagename, $args = '') {
	if( ! function_exists('GridWorks2')) {

		$gridworks = _GridWorks($pagename, $args);
		$error = _GridWorksLoadLib($gridworks);
		return @$error;

	} else {
		return GridWorks2($pagename, $args);
	}
}
